import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleBand,
  scaleLinear,
  max,
  axisBottom,
  axisLeft,
} from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/Yashwanth0402/04b7203b2f268da4efbe169a4184be40/raw/6e816a70cc5d744d07fdf9ce5e256fe6764d6938/ICE6';

const height = 500;
const width = 960;
const margin = {
  top: 20,
  right: 20,
  bottom: 70,
  left: 100,
};

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = (d) => {
      return { City: d.City, Temperature: +d.Temperature };
    };

    csv(csvUrl, row).then((data) => {
      setData(data);
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const xScale = scaleBand()
    .domain(data.map((d) => d.City))
    .range([0, innerWidth])
    .padding(0.1);

  const yScale = scaleLinear()
    .domain([0, max(data, (d) => d.Temperature) + 10]) // Increased upper limit by 10 units
    .range([innerHeight, 0]);

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        {data.map((d, index) => (
          <rect
            key={d.City}
            x={xScale(d.City)}
            y={yScale(d.Temperature)}
            width={xScale.bandwidth()}
            height={innerHeight - yScale(d.Temperature)}
            fill="blue" // Blue fill color
          />
        ))}
        <g
          transform={`translate(0,${innerHeight})`}
          ref={(node) =>
            axisBottom(xScale)(d3.select(node))
          }
        />
        <g
          ref={(node) => axisLeft(yScale)(d3.select(node))}
        />
      </g>
      <text
        x={margin.left + innerWidth / 2}
        y={height - margin.bottom / 3}
        textAnchor="middle"
        fontSize="16"
      >
        Cities
      </text>
      <text
        x={-innerHeight / 2}
        y={margin.left / 2}
        transform={`rotate(-90)`}
        textAnchor="middle"
        fontSize="16"
      >
        Temperature
      </text>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
